@@ -1,7 +1,4 @@
 package Perl6::Pod::Lib;
-
-#$Id$
-
 =pod
 
 =head1 NAME
@@ -12,14 +9,12 @@ Perl6::Pod::Lib - set of extensions for Perl6::Pod
 
 
     =begin pod
-    =use Perl6::Pod::Lib
     =Image src/test.jpg
     =end pod
 
 
     =begin pod
-    =use Perl6::Pod::Lib::Include
-    =Include http://example.com/api.pod(head1 :public)
+    =Include api.pod
     =end pod
 
     pod6xhtml -M Perl6::Pod::Lib somefile.pod  > somefile.xhtml
@@ -41,8 +36,10 @@ Insert image
 =back
 
 =cut
+use Perl6::Pod::Lib::Image;
+use Perl6::Pod::Lib::Include;
 
-$Perl6::Pod::Lib::VERSION = '0.07';
+$Perl6::Pod::Lib::VERSION = '0.10';
 our $PERL6POD = <<POD;
 =begin pod
 =use Perl6::Pod::Lib::Image
@@ -50,6 +47,13 @@ our $PERL6POD = <<POD;
 =end pod
 POD
 
+#package variable for map blocks and classes
+
+our $POD6USE = {
+'Image'=>'Perl6::Pod::Lib::Image',
+'Include'=>'Perl6::Pod::Lib::Include'
+};
+
 1;
 __END__
 
@@ -66,10 +70,10 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2011 by Zahatski Aliaksandr
+Copyright (C) 2010-2012 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
+it under the same terms as Perl itself, either Perl version 5.10 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
