@@ -14,77 +14,55 @@ use base 'TBase';
 
 sub p01_test_include_from_pod_with_patterns : Test {
     my $t = shift;
-    my $x = $t->parse_to_xml( <<T, );
+    my $x = $t->parse_to_test( <<T, );
 =begin pod
-=Include t/data/P_test1.pod(para :aa)
+=Include t/data/P_test1.pod
 =end pod
 T
-    $t->is_deeply_xml(
-        $x,
-q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><Include pod:type='block'><para pod:type='block' aa='1'>para1
-</para></Include></pod>#
-    );
+    my $i1 = $x->{Include}->[0];
+    is $i1->{PATH}, 't/data/P_test1.pod', '=Include t/data/P_test1.pod';
 }
 
 sub p02_test_xhtml : Test {
     my $t = shift;
     my $x = $t->parse_to_xhtml( <<T, );
 =begin pod
-=Include t/data/P_test1.pod(para :aa)
+=Include t/data/P_test1.pod
 =end pod
 T
     $t->is_deeply_xml(
         $x,
-        q#<xhtml xmlns='http://www.w3.org/1999/xhtml'><p>para1
-</p></xhtml>#
+        q#<xhtml xmlns="http://www.w3.org/1999/xhtml"><h1>Test
+ </h1><h1>Test1 This is content
+ </h1><h2>test level2
+ </h2><p>para1
+ </p><p>This is a secure hole !
+ </p><h1>test
+ </h1><p>This is a public gate..
+ </p></xhtml>#
     );
 }
 
 sub p03_test_docbook : Test {
-    my $t = shift;
+my $t = shift;
     my $x = $t->parse_to_docbook( <<T, );
 =begin pod
-=Include t/data/P_test1.pod(para :aa)
+=Include t/data/P_test1.pod
 =end pod
 T
     $t->is_deeply_xml(
         $x,
-        q#<chapter><para aa='1'>para1
-</para></chapter>#
+        q#<chapter><section><title>Test
+</title></section><section><title>Test1 This is content
+</title><section><title>test level2
+</title><para>para1
+</para><para>This is a secure hole !
+</para></section><title>test
+</title><para>This is a public gate..
+</para></section></chapter>#
     );
 }
 
-sub p04_test_2_exp : Test {
-    my $t = shift;
-    my $x = $t->parse_to_xml( <<T, );
-=begin pod
-=Include t/data/P_test1.pod(para :aa, para :private)
-=end pod
-T
-    $t->is_deeply_xml(
-        $x,
-q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><Include pod:type='block'><para pod:type='block' aa='1'>para1
-</para><para pod:type='block' private='1'>This is a secure hole !
-</para></Include></pod>#
-    );
-}
-
-sub p05_test_attr_only : Test {
-    my $t = shift;
-    my $x = $t->parse_to_xml( <<T, );
-=begin pod
-=Include t/data/P_test1.pod(:private)
-=end pod
-T
-    $t->is_deeply_xml(
-        $x,
-q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><Include pod:type='block'><head1 pod:type='block' private='1'>Test1 This is content
-</head1><para pod:type='block' private='1'>This is a secure hole !
-</para></Include></pod>#
-      )
-
-}
-
 sub p06_deep_include : Test {
     my $t = shift;
     my $x = $t->parse_to_xhtml( <<T, );
@@ -100,21 +78,6 @@ q#<xhtml xmlns='http://www.w3.org/1999/xhtml'><p>Deep include
       )
 }
 
-sub p07_exclude : Test {
-    my $t = shift;
-    my $x = $t->parse_to_xhtml( <<T, );
-=begin pod
-=Include t/data/test2_exclude.pod (!Describe)
-=end pod
-T
-    $t->is_deeply_xml(
-        $x,
-q#<xhtml xmlns='http://www.w3.org/1999/xhtml'><h1>Test
-</h1></xhtml>
-#
-      )
-}
-
 
 1;
 
